@@ -179,9 +179,29 @@ class VisualizationFunctions:
             DCS.makeHeatmapGeneExpressionPlot()
         '''
 
+        lengthListGenes = []
+        labelsListGenes = []
+
         if not genes is None:
-            if convertGenes:
-                genes = np.unique(self.gnc.Convert(genes, 'alias', 'hugo', returnUnknownString=False))
+            if type(genes) in [list, np.array, tuple]:
+                if convertGenes:
+                    genes = np.unique(self.gnc.Convert(genes, 'alias', 'hugo', returnUnknownString=False))
+
+            elif type(genes) in [dict]:
+                if convertGenes:
+                    for key in genes.keys():
+                        genes[key] = self.gnc.Convert(genes[key], 'alias', 'hugo', returnUnknownString=False)
+
+                lengthListGenes = []
+                listGenes = []
+                for key in genes.keys():
+                    listGenes.extend(genes[key])
+                    lengthListGenes.append(len(genes[key]))
+                    labelsListGenes.append(key)
+
+                genes = listGenes
+                print('Length of genes lists:', lengthListGenes)
+
         else:
             if self.verbose >= 1:
                 print('Plotting all expressed genes not supported. Provide a smaller list of genes')
@@ -195,7 +215,7 @@ class VisualizationFunctions:
             if self.df_expr is None:
                 return
 
-            common = pd.Index(genes).intersection(self.df_expr.index).drop_duplicates()
+            common = pd.Index(genes).intersection(self.df_expr.index) #.drop_duplicates()
             df = self.df_expr.loc[common].copy()
 
         else:
@@ -237,6 +257,13 @@ class VisualizationFunctions:
 
         ax.axhline(y=0.5, c='k', lw=1.5)
 
+        if len(lengthListGenes) != 0:
+            currPosition = 0
+            for label, value in zip(labelsListGenes, lengthListGenes):
+                currPosition += value
+                ax.axvline(x=currPosition - 0.5, c='k', lw=1)
+                ax.text(currPosition - 0.5*value - 0.5, df.shape[1], label, fontsize=10, c='k', ha='center', va='bottom')
+
         ax.set_xticks(range(df.shape[0]))
         ax.set_yticks(range(df.shape[1]))
 
